@@ -1,7 +1,7 @@
 package Bencher::Scenario::CmdLineParsingModules;
 
 our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -65,7 +65,7 @@ Bencher::Scenario::CmdLineParsingModules - Benchmark command-line parsing module
 
 =head1 VERSION
 
-This document describes version 0.05 of Bencher::Scenario::CmdLineParsingModules (from Perl distribution Bencher-Scenario-CmdLineParsingModules), released on 2017-01-25.
+This document describes version 0.06 of Bencher::Scenario::CmdLineParsingModules (from Perl distribution Bencher-Scenario-CmdLineParsingModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -137,14 +137,14 @@ Benchmark with default options (C<< bencher -m CmdLineParsingModules >>):
  +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
  | participant                            | dataset      | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
- | Parse::CommandLine::parse_command_line | 4args        |     34400 | 29.1      |      1     | 1.2e-08 |      23 |
- | Complete::Bash::parse_cmdline          | 4args        |     37600 | 26.6      |      1.09  | 1.3e-08 |      20 |
- | Complete::Bash::parse_cmdline          | 2args-simple |     93300 | 10.7      |      2.71  | 3.1e-09 |      23 |
- | Parse::CommandLine::parse_command_line | 2args-simple |    140000 |  7.4      |      4     |   1e-08 |      33 |
- | Complete::Bash::parse_cmdline          | cmd-only     |    200000 |  4.9      |      5.9   | 1.8e-08 |      30 |
- | Parse::CommandLine::parse_command_line | cmd-only     |    353000 |  2.83     |     10.3   | 7.5e-10 |      25 |
- | Complete::Bash::parse_cmdline          | empty        |    680000 |  1.5      |     20     | 6.5e-09 |      21 |
- | Parse::CommandLine::parse_command_line | empty        |   2949840 |  0.339001 |     85.764 |   0     |      20 |
+ | Parse::CommandLine::parse_command_line | 4args        |     34000 | 29.4      |     1      | 1.2e-08 |      24 |
+ | Complete::Bash::parse_cmdline          | 4args        |     38100 | 26.2      |     1.12   | 1.3e-08 |      20 |
+ | Complete::Bash::parse_cmdline          | 2args-simple |     93000 | 11        |     2.7    | 1.3e-08 |      20 |
+ | Parse::CommandLine::parse_command_line | 2args-simple |    137000 |  7.29     |     4.03   | 3.3e-09 |      20 |
+ | Complete::Bash::parse_cmdline          | cmd-only     |    220000 |  4.5      |     6.5    | 6.5e-09 |      21 |
+ | Parse::CommandLine::parse_command_line | cmd-only     |    354000 |  2.82     |    10.4    | 6.7e-10 |      31 |
+ | Complete::Bash::parse_cmdline          | empty        |   1300000 |  0.8      |    37      | 1.7e-09 |      20 |
+ | Parse::CommandLine::parse_command_line | empty        |   2949820 |  0.339004 |    86.6955 |   0     |      20 |
  +----------------------------------------+--------------+-----------+-----------+------------+---------+---------+
 
 
@@ -154,9 +154,9 @@ Benchmark module startup overhead (C<< bencher -m CmdLineParsingModules --module
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Complete::Bash      | 0.83                         | 4.1                | 16             |       9   |                    4.1 |        1   |   2e-05 |      23 |
- | Parse::CommandLine  | 1.1                          | 4.5                | 16             |       8.8 |                    3.9 |        1   | 3.7e-05 |      20 |
- | perl -e1 (baseline) | 1                            | 4.3                | 16             |       4.9 |                    0   |        1.8 | 1.3e-05 |      21 |
+ | Parse::CommandLine  | 1.1                          | 4.4                | 16             |       9.5 |                    4   |        1   | 3.9e-05 |      20 |
+ | Complete::Bash      | 0.82                         | 4.1                | 16             |       9.4 |                    3.9 |        1   | 1.8e-05 |      20 |
+ | perl -e1 (baseline) | 1                            | 4.5                | 16             |       5.5 |                    0   |        1.7 | 1.5e-05 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
