@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::CmdLineParsingModules;
 
-our $VERSION = 0.05; # VERSION
+our $VERSION = 0.06; # VERSION
 
 our $results = [
   [
@@ -11,73 +11,73 @@ our $results = [
         dataset     => "4args",
         errors      => 1.2e-08,
         participant => "Parse::CommandLine::parse_command_line",
-        rate        => 34400,
-        samples     => 23,
-        time        => 29.1,
+        rate        => 34000,
+        samples     => 24,
+        time        => 29.4,
         vs_slowest  => 1,
       },
       {
         dataset     => "4args",
         errors      => 1.3e-08,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 37600,
+        rate        => 38100,
         samples     => 20,
-        time        => 26.6,
-        vs_slowest  => 1.09,
+        time        => 26.2,
+        vs_slowest  => 1.12,
       },
       {
         dataset     => "2args-simple",
-        errors      => 3.1e-09,
+        errors      => 1.3e-08,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 93300,
-        samples     => 23,
-        time        => 10.7,
-        vs_slowest  => 2.71,
+        rate        => 93000,
+        samples     => 20,
+        time        => 11,
+        vs_slowest  => 2.7,
       },
       {
         dataset     => "2args-simple",
-        errors      => 1e-08,
+        errors      => 3.3e-09,
         participant => "Parse::CommandLine::parse_command_line",
-        rate        => 140000,
-        samples     => 33,
-        time        => 7.4,
-        vs_slowest  => 4,
+        rate        => 137000,
+        samples     => 20,
+        time        => 7.29,
+        vs_slowest  => 4.03,
       },
       {
         dataset     => "cmd-only",
-        errors      => 1.8e-08,
+        errors      => 6.5e-09,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 200000,
-        samples     => 30,
-        time        => 4.9,
-        vs_slowest  => 5.9,
+        rate        => 220000,
+        samples     => 21,
+        time        => 4.5,
+        vs_slowest  => 6.5,
       },
       {
         dataset     => "cmd-only",
-        errors      => 7.5e-10,
+        errors      => 6.7e-10,
         participant => "Parse::CommandLine::parse_command_line",
-        rate        => 353000,
-        samples     => 25,
-        time        => 2.83,
-        vs_slowest  => 10.3,
+        rate        => 354000,
+        samples     => 31,
+        time        => 2.82,
+        vs_slowest  => 10.4,
       },
       {
         dataset     => "empty",
-        errors      => 6.5e-09,
+        errors      => 1.7e-09,
         participant => "Complete::Bash::parse_cmdline",
-        rate        => 680000,
-        samples     => 21,
-        time        => 1.5,
-        vs_slowest  => 20,
+        rate        => 1300000,
+        samples     => 20,
+        time        => 0.8,
+        vs_slowest  => 37,
       },
       {
         dataset     => "empty",
         errors      => 0,
         participant => "Parse::CommandLine::parse_command_line",
-        rate        => 2949840,
+        rate        => 2949820,
         samples     => 20,
-        time        => 0.339001,
-        vs_slowest  => 85.764,
+        time        => 0.339004,
+        vs_slowest  => 86.6955,
       },
     ],
     {
@@ -200,7 +200,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2789.882,
+                                              speed                        => 2600.007,
                                               stepping                     => 4,
                                             },
                                             {
@@ -315,7 +315,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2600.062,
+                                              speed                        => 2708.726,
                                               stepping                     => 4,
                                             },
                                             {
@@ -430,7 +430,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2654.968,
+                                              speed                        => 2755.265,
                                               stepping                     => 4,
                                             },
                                             {
@@ -545,13 +545,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2857.968,
+                                              speed                        => 2717.421,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.239529132843018,
+      "func.elapsed_time"              => 0.198591947555542,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::CmdLineParsingModules" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Complete::Bash" => 0.31,
@@ -591,9 +592,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1467033075,
       "func.scenario_module_sha1sum"   => "98de2dc9dad823f84373d07a0b901f6630790db5",
       "func.scenario_module_sha256sum" => "3425def50615dd4e2132f6358b606c217c14e891016e8231cd134d9becb24c45",
-      "func.time_end"                  => 1485315282.9399,
+      "func.time_end"                  => 1485317488.84062,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1485315282.70037,
+      "func.time_start"                => 1485317488.64203,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
